@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * with this program. If not, see <http://www.gnu.org/licenses/>
  *
  * Authors:
  *   Daniel P. Berrange <berrange@redhat.com>
@@ -290,7 +289,7 @@ gint main(gint argc, gchar **argv)
     if (custom)
         locs++;
     if (locs > 1 || (locs && argc > 1)) {
-        g_printerr(_("Only one of --user, --local, --system, --dir or positional filenames can be used"));
+        g_printerr(_("Only one of --user, --local, --system, --dir or positional filenames can be used\n"));
         goto error;
     }
 
